@@ -1,5 +1,5 @@
 """Cut a mesh with another mesh"""
-from vedo import *
+from vedo import dataurl, settings, Plotter, Volume, Ellipsoid
 
 settings.tiffOrientationType = 4 # data origin is bottom-left
 
@@ -11,5 +11,7 @@ msh = Ellipsoid().scale(0.4).pos(2.8, 1.5, 1.5).wireframe()
 # make a working copy and cut it with the ellipsoid
 cutembryo = embryo.clone().cutWithMesh(msh).c("gold").bc("t")
 
-show(embryo, msh,    at=0, N=2, axes=1, viewup="z")
-show(cutembryo, __doc__, at=1, interactive=True).close()
+plt = Plotter(N=2, axes=1)
+plt.at(0).show(embryo, msh, viewup="z")
+plt.at(1).show(cutembryo, __doc__)
+plt.interactive().close()
