@@ -6,16 +6,17 @@ Blue points are the N points used for fitting"""
 from vedo import *
 
 settings.defaultFont = 'Kanopus'
+settings.useDepthPeeling = True
 
 plt = Plotter()
 
 # load mesh and increase by a lot (N=2) the nr of surface vertices
-s = plt.load(dataurl+"cow.vtk").alpha(0.3).subdivide(N=2)
+cow = Mesh(dataurl+"cow.vtk").alpha(0.3).subdivide(N=2)
 
-for i, p in enumerate(s.points()):
+for i, p in enumerate(cow.points()):
     if i % 1000:
         continue  # skip most points
-    pts = s.closestPoint(p, N=16)  # find the N closest points to p
+    pts = cow.closestPoint(p, N=16)  # find the N closest points to p
     sph = fitSphere(pts).alpha(0.05)  # find the fitting sphere
     if sph is None:
         continue  # may fail if all points sit on a plane
@@ -23,5 +24,5 @@ for i, p in enumerate(s.points()):
     plt += Points(pts)
     plt += Line(sph.center, p, lw=2)
 
-plt += __doc__
+plt += [cow, __doc__]
 plt.show(viewup="z", axes=1).close()
