@@ -1,6 +1,5 @@
 """A textured gyroid shape cut by a sphere"""
 from vedo import *
-import numpy as np
 
 # Equation of a "gyroid" (https://en.wikipedia.org/wiki/Gyroid)
 x, y, z = np.mgrid[:30,:30,:30] * 0.4
@@ -12,10 +11,12 @@ gyr = Volume(U).isosurface(0).smooth().subdivide()
 # Intersect it with a sphere made of quads
 sph = Sphere(pos=(15,15,15), r=14, quads=True, res=30).triangulate()
 printc("Please wait a few secs while I'm cutting your gyroid", c='y')
-gxs = gyr.boolean('intersect', sph).clean().flat()
+gxs = gyr.boolean('intersect', sph)
 gxs.texture('https://vedo.embl.es/examples/data/images/marblings.jpg')
 
-plt = show(gxs, __doc__, bg='wheat', bg2='lightblue', axes=5, zoom=1.4)
+plt = Plotter(bg='wheat', bg2='lightblue', axes=5)
+plt.addAmbientOcclusion(10)
+plt.show(gxs, __doc__, zoom=1.4)
 # Video('gyroid.mp4').action().close().interactive() # shoot video
 plt.close()
 
