@@ -1,6 +1,5 @@
-"""Generate a polygonal Mesh
-from a contour line"""
-from vedo import *
+"""Generate a polygonal Mesh from a contour line"""
+from vedo import dataurl, load, Line, show
 from vedo.pyplot import histogram
 
 shapes = load(dataurl+'timecourse1d.npy') # list of lines
@@ -13,9 +12,12 @@ msh.addQuality()           # add a measure of triangle quality
 msh.cmap(cmap, on="cells").addScalarBar3D()
 
 contour = Line(shape).c('red4').lw(5)
-histo = histogram(msh.celldata['Quality'], aspect=3/4,
-                  c=cmap, xtitle='triangle mesh quality')
-show([(contour, contour.labels('id'), msh, __doc__),
-      histo,
-     ], N=2, sharecam=False,
-).close()
\ No newline at end of file
+labels  = contour.labels('id')
+
+histo = histogram(msh.celldata['Quality'],
+                  xtitle='triangle mesh quality',
+                  aspect=3/4,
+                  c=cmap,
+)
+
+show([(contour, labels, msh, __doc__), histo], N=2, sharecam=0).close()
