@@ -1,7 +1,7 @@
 """Metrics of quality for
 the cells of a triangular mesh
 (zoom to see cell label values)"""
-from vedo import *
+from vedo import dataurl, Mesh, show
 from vedo.pyplot import histogram
 
 mesh = Mesh(dataurl+"panther.stl").computeNormals().lineWidth(0.1).flat()
@@ -9,7 +9,7 @@ mesh = Mesh(dataurl+"panther.stl").computeNormals().lineWidth(0.1).flat()
 # generate a numpy array for mesh quality
 mesh.addQuality(measure=6).cmap('RdYlBu', on='cells').print()
 
-hist = histogram(mesh.celldata["Quality"], xtitle='mesh quality', bc='w')
+hist = histogram(mesh.celldata["Quality"], xtitle='mesh quality', ac='w')
 # make it smaller and position it, useBounds makes the cam
 # ignore the object when resetting the 3d qscene
 hist.scale(0.6).pos(40,-53,0).useBounds(False)
