@@ -7,7 +7,8 @@ rim  = Mesh(dataurl + "270_rim.vtk").c("red").lw(4)
 
 # Make a clone copy of rim and align it to limb
 # rigid=True doesn't allow scaling
-rim2 = rim.clone().alignTo(limb, rigid=True).c("green").lw(5)
+rim2 = rim.clone().alignTo(limb, rigid=True)
+rim2.c("green").lw(5)
 
 d = 0
 for p in rim2.points():
@@ -16,6 +17,6 @@ for p in rim2.points():
 
 printc("ave. squared distance =", d/rim2.N())
 # vtkTransform is available through:
-# printc([rim2.transform])
+#printc([rim2.transform])
 
 show(limb, rim, rim2, __doc__, axes=1).close()
