@@ -6,10 +6,10 @@ b = Mesh(dataurl+'290.vtk')
 b.computeNormals().clean().lw(0.1)
 
 pids = b.boundaries(returnPointIds=True)
-bpts = b.points()[pids]
+bpts = b.points()
 
-pts = Points(bpts, r=10, c='red')
+pts = Points(bpts[pids], r=10, c='red5')
 
-labels = b.labels('id', scale=10).c('dg')
+labels = b.labels('id', scale=10).c('green2')
 
-show(b, pts, labels, __doc__, zoom=2).close()
\ No newline at end of file
+show(b, pts, labels, __doc__, zoom=2).close()
