@@ -7,6 +7,6 @@ a = Mesh(dataurl+"bunny.obj").lw(0.1).bc('red')
 
 # size = approximate limit to the size of the hole to be filled.
 b = a.clone().pos(.2,0,0).fillHoles(size=0.1)
-b.color("lb").bc('green').legend("filled mesh")
+b.color("lb").bc('green')
 
-show(a, b, __doc__, elevation=-70).close()
+show(a, b, __doc__).close()
