@@ -19,6 +19,6 @@ pts.name = 'The cube vertices'  # can give a name to any objects
 plt = Plotter(N=2, axes=1, sharecam=False)
 
 # Add a 2D hover legend to both renderers and show:
-plt.addHoverLegend(at=0).show(mesh, sph, __doc__, at=0)
-plt.addHoverLegend(at=1).show(cub, pts, at=1)
-plt.interactive().close()
\ No newline at end of file
+plt.at(0).addHoverLegend().show(mesh, sph, __doc__)
+plt.at(1).addHoverLegend().show(cub, pts)
+plt.interactive().close()
