@@ -3,7 +3,7 @@ pressing a keyboard button when the rendering window
 is in interactive mode
 
 Place pointer anywhere on the mesh and press c"""
-from vedo import *
+from vedo import dataurl, printc, Plotter, Point, Mesh
 
 #############################################################
 def myfnc(evt):
@@ -12,7 +12,6 @@ def myfnc(evt):
     if not mesh or evt.keyPressed != "c":
         printc("click mesh and press c", c="r")
         return
-    #printc("mesh :", mesh.filename, c=mesh.color())
     printc("point:", mesh.picked3d, c="v")
     cpt = Point(pos=mesh.picked3d, r=20, c="v").pickable(False)
     plt.add(cpt)
