@@ -19,7 +19,7 @@ plt = Plotter(shape=custom_shape, size=(1200,900))
 for i in range(len(custom_shape)):
     s = ParametricShape(i).color(i).lighting('glossy')
     msg = 'Renderer nr.'+str(i)+'\n'+str(custom_shape[i])+'\nShape = '+s.name
-    plt.show(s, msg, at=i)
+    plt.at(i).show(s, msg)
 
-plt.add(Text2D(__doc__, pos='bottom-right', font="Quikhand", s=1.5), at=0)
+plt.at(0).add(Text2D(__doc__, pos='bottom-right', font="Quikhand", s=1.5))
 plt.interactive().close()
