@@ -4,7 +4,7 @@ from vtk.qt.QVTKRenderWindowInteractor import QVTKRenderWindowInteractor
 from vedo import Plotter, Picture, Text2D, printc
 
 class MainWindow(Qt.QMainWindow):
-    
+
     def __init__(self, parent=None):
 
         Qt.QMainWindow.__init__(self, parent)
@@ -13,8 +13,8 @@ class MainWindow(Qt.QMainWindow):
         self.vtkWidget = QVTKRenderWindowInteractor(self.frame)
 
         # Create vedo renderer and add objects and callbacks
-        self.vp = Plotter(qtWidget=self.vtkWidget)
-        self.cbid = self.vp.addCallback("key press", self.onKeypress)
+        self.plt = Plotter(qtWidget=self.vtkWidget)
+        self.cbid = self.plt.addCallback("key press", self.onKeypress)
         self.imgActor = Picture("https://icatcare.org/app/uploads/2018/07/Helping-your-new-cat-or-kitten-settle-in-1.png")
         self.text2d = Text2D("Use slider to change contrast")
 
@@ -25,22 +25,22 @@ class MainWindow(Qt.QMainWindow):
 
         self.frame.setLayout(self.layout)
         self.setCentralWidget(self.frame)
-        self.vp.show(self.imgActor, self.text2d, mode='image') # build the vedo rendering
+        self.plt.show(self.imgActor, self.text2d, mode='image') # build the vedo rendering
         self.show()                                            # show the Qt Window
 
-           
+
     def onSlider(self, value):
         self.imgActor.window(value*10) # change image contrast
         self.text2d.text(f"window level is now: {value*10}")
-        self.vp.render()
+        self.plt.render()
 
     def onKeypress(self, evt):
         printc("You have pressed key:", evt.keyPressed, c='b')
         if evt.keyPressed=='q':
-            self.vp.close()
+            self.plt.close()
             self.vtkWidget.close()
             exit()
-            
+
     def onClose(self):
         self.vtkWidget.close()
 
