@@ -12,7 +12,7 @@ mesh = trimesh.load_mesh(f)
 txt = 'cross section of the mesh'
 mslice = mesh.section(plane_origin=mesh.centroid, plane_normal=[0,0,1])
 
-pl = Plane(mesh.centroid, normal=[0,0,1], sx=6, sy=4, c='green', alpha=0.3)
+pl = Plane(mesh.centroid, normal=[0,0,1], s=[6,4], c='green', alpha=0.3)
 
 slice_2D, to_3D = mslice.to_planar()
 
@@ -40,5 +40,5 @@ combined = np.sum(sections)
 sections.append([combined, 'combined'])
 
 # show objects in N synced renderers:
-show(sections, N=N, axes=True, new=True, interactive=True).close()
+show(sections, N=N, axes=1, new=True).interactive().close()
 
