@@ -2,7 +2,7 @@
 areas are proportional to energy release
 [hover mouse to get more info]"""
 import pandas, numpy as np
-from vedo import download, Picture, Polygon, ProgressBar, colorMap, Plotter, Text2D
+from vedo import download, Picture, ProgressBar, colorMap, Plotter, Text2D, GeoCircle
 
 num = 50  # nr of earthquakes to be visualized to define a time window
 path = download("https://earthquake.usgs.gov/earthquakes/feed/v1.0/summary/2.5_month.csv")
@@ -13,17 +13,6 @@ pic = Picture("https://eoimages.gsfc.nasa.gov/images/imagerecords/147000/147190/
 pic.pickable(False).level(185).window(120)  # add some contrast to the original image
 scale = [pic.shape[0]/2, pic.shape[1]/2, 1]
 
-def GeoCircle(lat, lon, r, res=50):
-    coords = []
-    sinr, cosr = np.sin(r), np.cos(r)
-    sinlat, coslat = np.sin(lat), np.cos(lat)
-    for phi in np.linspace(0, 2*np.pi, num=res, endpoint=False):
-        clat = np.arcsin(sinlat * cosr + coslat * sinr * np.cos(phi))
-        clng = lon + np.arctan2(np.sin(phi) * sinr * coslat, cosr - sinlat * np.sin(clat))
-        coords.append([clng/np.pi + 1, clat*2/np.pi + 1, 0])
-    return Polygon(nsides=res).points(coords)  # warp polygon points to match geo projection
-
-
 centers = []
 pb = ProgressBar(0, len(data))
 for i, d in data.iterrows():
@@ -35,7 +24,6 @@ for i, d in data.iterrows():
     ce = GeoCircle(lat, lon, E/50).scale(scale).z(num/M).c(rgb).lw(0.1).useBounds(False)
     ce.time = i
     ce.info = '\n'.join(str(d).split('\n')[:-1])       # remove of the last line in string d
-    #if M > 6.5: ce.alpha(0.8)                         # make the big ones slightly transparent
     if i < len(data)-num: ce.off()                     # switch off older ones: make circles invisible
     centers.append(ce)
 
@@ -51,5 +39,5 @@ def sliderfunc(widget, event):
 plt = Plotter(size=(2200,1100), title="Earthquake Browser")
 plt.addSlider2D(sliderfunc, 0, len(centers)-1, value=len(centers)-1, showValue=False, title="today")
 plt.addHoverLegend(useInfo=True, alpha=1, c='white', bg='red2', s=1)
-comment = Text2D(__doc__, bg='green9', alpha=0.7)
+comment = Text2D(__doc__, bg='green9', alpha=0.7, font='Ubuntu')
 plt.show(pic, centers, comment, zoom=2.27, mode='image').close()
