@@ -5,24 +5,26 @@ import numpy as np
 # np.random.seed(0)
 
 # Generate some noisy data points along a line
-x = np.linspace(0, 15, 25)
 a, b = (np.random.rand(2)-0.5)*10 # choose a and b
+
+x = np.linspace(0, 15, 25)
 y = a*x + b
 noise = np.random.randn(len(x)) * 5 # create gaussian noise
 
-# Plot the points and the "true" line without noise
-plt = plot(x, y+noise, '*k', title=__doc__)
-plt += DashedLine(x, y)
+# Plot the points and add the "true" line without noise
+fig = plot(x, y+noise, '*k', title=__doc__, label='data')
+fig += DashedLine(x, y, c='red5')
 
 # Fit points and evaluate, with a boostrap and Monte-Carlo technique,
 # the correct error coeffs and error bands. Return a Line object:
-pfit = fit([x, y+noise],
-           deg=1,          # degree of the polynomial
-           niter=500,      # nr. of MC iterations to compute error bands
-           nstd=2,         # nr. of std deviations to display
+pfit = fit(
+    [x, y+noise],
+    deg=1,          # degree of the polynomial
+    niter=500,      # nr. of MC iterations to compute error bands
+    nstd=2,         # nr. of std deviations to display
 )
 
-plt += [pfit, pfit.errorBand, *pfit.errorLines] # add these objects to Plot
+fig += [pfit, pfit.errorBand, *pfit.errorLines] # add these objects to fig
 
 msg = f"Generated a, b  : {np.array([a,b])}"\
       f"\nFitted    a, b  : {pfit.coefficients}"\
@@ -30,4 +32,9 @@ msg = f"Generated a, b  : {np.array([a,b])}"\
       f"\nave point spread: \sigma \approx {pfit.dataSigma:.3f} in y units"
 msg = Text2D(msg, font='VictorMono', pos='bottom-left', c='red3')
 
-show(plt, msg, mode="image").close()
+fig.addLabel("y = a\dotx+b", c='k', marker='-', mc='red4')
+fig.addLabel("ground truth", c='k', marker='--', mc='red5')
+fig.addLabel("1\sigma error band", c='k', marker='s', mc='grey')
+fig.addLegend(pos=[1.07,1], vspace=2)
+
+show(fig, msg, zoom=1.1).close()
