@@ -1,20 +1,61 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-from vedo import printc, Text2D, Text3D, show, settings, Line, Plotter, shapes
-from vedo import fonts, fonts_path
+from vedo import printc, Text2D, Text3D, show, Plotter, shapes
+from vedo import fonts, fonts_path, settings
 import numpy as np
 import os
 
+settings.allowInteraction = True
 
 ################################################################################## 2D
-acts2d = []
+inred = Text2D("°monospaced fonts are marked in red", c='r5', pos='bottom-center', font='VictorMono')
+acts2d = [inred]
+
+txt = 'The quick fox jumps over the lazy dog. 1234567890 αβγδεθλμνπστφψω'
 for i, f in enumerate(fonts):
-    t = Text2D(f+': The quick fox jumps over the lazy dog. 1234567890 αβγδεθλμνπστφψω',
-               pos=(.015, 1-(i+3)*.06), font=f, s=1.3, c='k')
+    bg = None
+    if f in ['Calco', 'Glasgo', 'SmartCouric', 'VictorMono']:
+        bg = 'red5'
+    t = Text2D(f'{f}: {txt}', pos=(.015, 1-(i+3)*.06), font=f, s=1.3, c='k', bg=bg)
     acts2d.append(t)
 
-acts2d.append(Text2D("List of Available Fonts", pos='top-center', bg='k', s=1.1))
-plt0 = show(acts2d, bg2='cornsilk', axes=False, zoom=1.2, size=(1200,700), interactive=False)
+acts2d.append(Text2D("List of built-in fonts", pos='top-center', bg='k', s=1.3))
+plt0a = show(acts2d, bg2='cornsilk', size=(1300,800), interactive=False)
+
+## online fonts:
+acts2d = []
+i = 0
+for key, props in sorted(settings.font_parameters.items()):
+    if props['islocal']:
+        continue
+    if key=='Justino2' or key=='Justino3':
+        continue
+    bg = None
+    if props['mono']:
+        bg = 'red5'
+    t = Text2D(f'{key}: {txt}', pos=(.015, 1-(i+2)*.06), font=key, s=1.3, c='k', bg=bg)
+    acts2d.append(t)
+    i+=1
+plt0b = show(acts2d,
+             Text2D("Additional fonts (https://vedo.embl.es/fonts)", pos='top-center', bg='k', s=1.3),
+             bg2='lb', size=(1300,900), pos=(1200,200), new=True)
+
+################################################################################ printout
+for font in fonts:
+    printc(font + " - available characters:", " "*25, bold=1, invert=1)
+    fontfile = os.path.join(fonts_path, font + '.npz')
+    font_meshes = np.load(fontfile, allow_pickle=True)['font'][0]
+    for k in font_meshes.keys():
+        printc(k, end=' ')
+    print()
+
+printc('\n(use the above to copy&paste any char into your python script!)', italic=1)
+printc('Symbols ~ ^ _ are reserved modifiers:', italic=1)
+printc(' use ~ to add a short space, 1/4 of the default size,', italic=1)
+printc(' use ^ and _ to start up/sub scripting, space terminates them.\n', italic=1)
+printc('Supported LaTeX tags:', box='-', c='y')
+for r in shapes._reps:
+    print('\\'+repr(r[0]).replace("'","").replace("\\",""),' = ', r[1])
 
 
 ################################################################################## 3D
@@ -43,6 +84,7 @@ cam = dict(pos=(3.99e+5, 8.51e+3, 6.47e+5),
 
 for i,fnt in enumerate(["Kanopus", "Normografo", "Theemim", "VictorMono"]):
     t = Text3D(txt, font=fnt, italic=0).c('darkblue').scale(12300)
+    plt.at(i)
     plt.show(t,
              Text2D("Font: "+fnt, font=fnt, bg='r'),
              axes=dict(xtitle='my units for L_x  (\mum)',
@@ -51,63 +93,10 @@ for i,fnt in enumerate(["Kanopus", "Normografo", "Theemim", "VictorMono"]):
                        labelFont=fnt,
                        digits=2,
                       ),
-             at=i,
              camera=cam,
              resetcam=not bool(i),
     )
+plt.interactive().close()
 
-################################################################################ printout
-for font in fonts:
-    printc(font + " - available characters are:", " "*25, bold=1, invert=1)
-    fontfile = os.path.join(fonts_path, font + '.npz')
-    font_meshes = np.load(fontfile, allow_pickle=True)['font'][0]
-    for k in font_meshes.keys():
-        printc(k, end=' ')
-    print()
-
-printc('\n(use the above to copy&paste any char into your python script!)', italic=1)
-printc('Symbols ~ ^ _ are reserved modifiers:', italic=1)
-printc(' use ~ to add a short space, 1/4 of the default size,', italic=1)
-printc(' use ^ and _ to start up/sub scripting, space terminates them.\n', italic=1)
-printc('Supported LaTeX tags:', box='-', c='y')
-
-for r in shapes._reps:
-    print('\\'+repr(r[0]).replace("'","").replace("\\",""),' = ', r[1])
-printc('Font Summary', c='g', box='-')
-for i, f in enumerate(fonts):
-    printc('Font: ', f, c='g')
-
-################################################################################## 3D
-cam = dict(pos=(55.8, -4.27, 107),
-           focalPoint=(27.1, -29.2, -0.0532),
-           viewup=(-0.0642, 0.976, -0.210),
-           distance=113,
-           clippingRange=(87.1, 147))
-
-ln1 = Line([-1,-2],[52,-2], lw=0.1, c='grey')
-fn3d=[ln1]
-gap = 0
-for i, font in enumerate(fonts):
-    txt = font+": abcdefghijklmnopqrtuvwxyz 1234567890"
-    if font in ["Theemim", "Kanopus", "Normografo", "VictorMono",
-                "Galax", "LogoType", "Comae", "LionelOfParis"]:
-         txt += "\n         αβγδεζηθκλμνξπρστφχψω ΔΘΛΞΠΣΦΨΩ"
-         gap -= 2
-    if font in ["VictorMono", "Kanopus", "LogoType", "Comae","LionelOfParis"]:
-        txt+= " БГДЖЗИЙКЛ"
-    gap -= 4
-    t2 = Text3D(txt, font=font, italic=0).c(i).y(gap)
-    ln = Line([-1,gap-1],[52,gap-1], lw=0.5, c='grey')
-    fn3d.extend([t2,ln])
-
-show(fn3d,
-     new=True,
-     pos=(400,100), size=(900,900), azimuth=20,
-     axes=9,
-     camera=cam,
-     bg2='bb',
-     bg='k',
-    ).close()
-
-plt.close()
-plt0.close()
+plt0b.close()
+plt0a.close()
