@@ -11,11 +11,19 @@ x = np.linspace(min(samples), max(samples), num=50)
 y = 1/(sigma*np.sqrt(2*np.pi)) * np.exp( -(x-mu)**2 /(2*sigma**2))
 dy = 1/np.sqrt(n)
 
-plt  = histogram(samples, title=__doc__,
-                 bins=bins, density=True, c='cyan3', aspect=8/7)
+fig = histogram(
+    samples,
+    title=__doc__,
+    bins=bins,
+    density=True,
+    c='cyan3',
+    aspect=9/7,
+    label="gaussian",
+)
 
-plt += plot(x, y, "-", lc='orange5')
-plt += plot(x, y*(1+dy), "--", lc='orange5', lw=2)
-plt += plot(x, y*(1-dy), "--", lc='orange5', lw=2)
+fig += plot(x, y, "-", lc='orange5', like=fig, label="some fit")
+fig += plot(x, y*(1+dy), "--", lc='orange5', lw=2, like=fig)
+fig += plot(x, y*(1-dy), "--", lc='orange5', lw=2, like=fig)
 
-plt.show(size=(800,700), zoom=1.2, mode="image").close()
+fig.addLegend()
+fig.show(size=(800,700), zoom="tight").close()
