@@ -3,7 +3,7 @@
 # https://github.com/gjbex/training-material/blob/master/Misc/Notebooks/hanoi.ipynb
 # Creative Commons Zero v1.0 Universal licence
 
-from vedo import Plotter, Cylinder, Box, ProgressBar, settings, interactive
+from vedo import Plotter, Cylinder, Box, ProgressBar
 from copy import deepcopy
 
 
@@ -56,7 +56,7 @@ disks = { hanoi.nr_disks - i : Cylinder(r=0.2*(hanoi.nr_disks-i+1), c=i)
           for i in range(hanoi.nr_disks) }
 
 plt = Plotter(interactive=False, size=(800, 600), bg='wheat', bg2='lb')
-plt += disks.values()
+plt += list(disks.values())
 plt += Box(pos=(3,0,-0.5), size=(12,4,0.1))
 cam = dict(
     pos=(14.60, -20.56, 7.680),
