@@ -11,7 +11,7 @@ scals = np.abs(coords[:, 1])     # let the scalar be the y of the point itself
 pts = Points(coords, r=9)
 pts.pointdata["scals"] = scals
 
-densecloud = pts.densify(0.1, closest=10, niter=1) # return a new pointcloud.Points
+densecloud = pts.densify(0.1, nclosest=10, niter=1) # return a new pointcloud.Points
 printc('nr. points increased', pts.N(), '\rightarrow ', densecloud.N(), c='lg')
 
 show([(pts, __doc__), densecloud], N=2, axes=1).close()
