@@ -1,4 +1,4 @@
-from vedo import Cone, Sphere, merge, Volume
+from vedo import Cone, Sphere, merge, Volume, dataurl, utils
 import numpy as np
 import vtk
 
@@ -73,9 +73,9 @@ print('pos',[5,6,0], cone.pos())
 assert np.allclose([5,6,0], cone.pos())
 
 
-###################################### addPos
-cone.pos(5,6,7).addPos(3,0,0)
-print('addPos',[8,6,7], cone.pos())
+###################################### shift
+cone.pos(5,6,7).shift(3,0,0)
+print('shift',[8,6,7], cone.pos())
 assert np.allclose([8,6,7], cone.pos())
 
 
@@ -168,13 +168,13 @@ assert np.array(sphere.faces()).shape == (2112, 3)
 
 
 ###################################### texture
-st = sphere.clone().texture('wood2')
+st = sphere.clone().texture(dataurl+'textures/wood2.jpg')
 print('texture test')
 assert isinstance(st.GetTexture(), vtk.vtkTexture)
 
 
 ###################################### deletePoints
-sd = sphere.clone().deletePoints(range(100))
+sd = sphere.clone().deleteCellsByPointIndex(range(100))
 print('deletePoints',sd.N() , sphere.N())
 assert sd.N() == sphere.N()
 print('deletePoints',sd.NCells() ,'<', sphere.NCells())
@@ -212,16 +212,18 @@ assert np.allclose(ss.zbounds(), [-3,3], atol=0.01)
 
 
 ###################################### averageSize
-print('averageSize',sphere.averageSize())
-assert 0.9 < sphere.averageSize() < 1.0
+print('averageSize', Sphere().scale(10).pos(1,3,7).averageSize())
+assert 9.9 < Sphere().scale(10).pos(1,3,7).averageSize() < 10.1
+
 print('diagonalSize',sphere.diagonalSize())
 assert 3.3 < sphere.diagonalSize() < 3.5
-print('maxBoundSize',sphere.maxBoundSize())
-assert 1.9 < sphere.maxBoundSize() < 2.1
+
 print('centerOfMass',sphere.centerOfMass())
 assert np.allclose(sphere.centerOfMass(), [0,0,0])
+
 print('volume',sphere.volume())
 assert 4.1 < sphere.volume() < 4.2
+
 print('area',sphere.area())
 assert 12.5 < sphere.area() < 12.6
 
@@ -254,12 +256,6 @@ print('normalize',s3.averageSize())
 assert 0.9 < s3.averageSize() < 1.1
 
 
-###################################### stretch
-c2 = cone.clone().stretch([0,0,0], [3,4,5])
-print('stretch',c2.maxBoundSize(), '>', 5)
-assert c2.maxBoundSize() > 5
-
-
 ###################################### crop
 c2 = cone.clone().crop(left=0.5)
 print('crop',np.min(c2.points()[:,0]), '>', -0.001)
@@ -328,3 +324,28 @@ iso = vol.isosurface(threshold=1.0)
 print('isosurface', iso.area())
 assert 2540 < iso.area() <  3000
 
+
+###################################### utils change of coords
+q = [5,2,3]
+q = utils.cart2spher(*q)
+q = utils.spher2cart(*q)
+print("cart2spher spher2cart", q)
+assert np.allclose(q, [5,2,3])
+q = utils.cart2cyl(*q)
+q = utils.cyl2cart(*q)
+print("cart2cyl cyl2cart", q)
+assert np.allclose(q, [5,2,3])
+q = utils.cart2cyl(*q)
+q = utils.cyl2spher(*q)
+q = utils.spher2cart(*q)
+print("cart2cyl cyl2spher spher2cart", q)
+assert np.allclose(q, [5,2,3])
+q = utils.cart2spher(*q)
+q = utils.spher2cyl(*q)
+q = utils.cyl2cart(*q)
+print("cart2spher spher2cyl cyl2cart", q)
+assert np.allclose(q, [5,2,3])
+
+######################################
+print("OK with test_actors")
+
