@@ -1,10 +1,35 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 """
-.. image:: https://user-images.githubusercontent.com/32848391/46815773-dc919500-cd7b-11e8-8e80-8b83f760a303.png
-
-A python module for scientific analysis and visualization of 3D objects and point clouds based on VTK and numpy.
+.. include:: ../docs/documentation.md
 """
+##### To generate documentation #######################################################
+# cd Projects/vedo
+# pip uninstall vedo
+# pdoc --html . --force -c lunr_search="{'fuzziness': 0, 'index_docstrings': True}"
+# chmod 755 html/ -R
+# mount_staging
+# rm ~/Projects/StagingServer/var/www/html/vtkplotter.embl.es/autodocs/html
+# mv html/ ~/Projects/StagingServer/var/www/html/vtkplotter.embl.es/autodocs/
+############## pdoc excludes
+__pdoc__ = {}
+__pdoc__['embedWindow'] = False
+__pdoc__['backends'] = False
+__pdoc__['cli'] = False
+__pdoc__['cmaps'] = False
+__pdoc__['version'] = False
+__pdoc__['base.BaseActor.getPointArray'] = False
+__pdoc__['base.BaseActor.getCellArray'] = False
+__pdoc__['base.BaseActor.addPointArray'] = False
+__pdoc__['base.BaseActor.addCellArray'] = False
+__pdoc__['pointcloud.Points.pointColors'] = False
+__pdoc__['pointcloud.Points.cellColors'] = False
+__pdoc__['pointcloud.Points.thinPlateSpline'] = False
+__pdoc__['pointcloud.Points.warpByVectors'] = False
+__pdoc__['pointcloud.Points.distanceToMesh'] = False
+
+#######################################################################################
+
 __author__     = "Marco Musy"
 __license__    = "MIT"
 __maintainer__ = "M. Musy"
@@ -25,7 +50,7 @@ from numpy import sin, cos, sqrt, exp, log, dot, cross  # just because useful
 #################################################
 from vedo.version import _version as __version__
 from vedo.utils import *
-from vedo.settings import _setts as settings
+import vedo.settings as settings
 from vedo.colors import *
 from vedo.shapes import *
 from vedo.io import *
@@ -40,12 +65,7 @@ from vedo.tetmesh import *
 from vedo.shapes import *
 from vedo.addons import *
 from vedo.plotter import *
-
-# HACK: need to uncomment this to generate html documentation
-#from vedo.dolfin import _inputsort
-#import vedo.base as base
-import vedo.docs as docs  # needed by spyder console, otherwise complains
-
+import vedo.applications as applications
 
 ##################################################################################
 ########################################################################## GLOBALS
@@ -112,29 +132,17 @@ plotter_instance = None
 notebook_plotter = None
 notebookBackend  = None
 
-interactorStyle = None  # internal use only
-
-## textures
-textures_path = os.path.join(installdir, "textures/")
-textures = []
-for f in os.listdir(textures_path):
-    tfn = f.split(".")[0]
-    if 'earth' in tfn: continue
-    textures.append(tfn)
-
 ## fonts
 fonts_path = os.path.join(installdir, "fonts/")
-fonts = []
-for f in os.listdir(fonts_path):
-    if '.npz' in f: continue
-    fonts.append(f.split(".")[0])
+fonts = [_f.split(".")[0] for _f in os.listdir(fonts_path) if '.npz' not in _f]
 fonts = list(sorted(fonts))
 
-
 ################################################################## deprecated
 @deprecated(reason="\x1b[7m\x1b[1m\x1b[31;1mPlease use Plotter(backend='...')\x1b[0m")
 def embedWindow(backend='ipyvtk', verbose=True):
-    """Use this function to control whether the rendering window is inside
+    """DEPRECATED: Please use Plotter(backend='...').
+
+    Function to control whether the rendering window is inside
     the jupyter notebook or as an independent external window"""
     global notebook_plotter, notebookBackend
 
