@@ -4,17 +4,15 @@
 Command Line Interface module
 -----------------------------
 
-.. code-block:: python
-
     # Type for help
     vedo -h
 
     # Some useful bash aliases:
     alias v='vedo '
-    alias vv='vedo -bg blackboard -bg2 gray3 -z 1.05 -k glossy -c blue9 '
     alias vr='vedo --run '        # to search and run examples by name
     alias vs='vedo -i --search '  # to search for a string in examples
     alias ve='vedo --eog '        # to view single and multiple images (press h for help)
+    alias vv='vedo -bg blackboard -bg2 gray3 -z 1.05 -k glossy -c blue9 '
 """
 import argparse
 import glob
@@ -31,7 +29,6 @@ from vedo import load
 from vedo import settings
 from vedo.colors import getColor
 from vedo.colors import printc
-from vedo.docs import tips
 from vedo.mesh import Mesh
 from vedo.picture import Picture
 from vedo.plotter import Plotter
@@ -55,7 +52,7 @@ def execute_cli():
         vedo.installdir = vedo.installdir.replace('vedo/','').replace('vedo\\','')
 
     if args.info is not None:
-        exe_info(args)
+        system_info()
 
     elif args.run:
         exe_run(args)
@@ -126,7 +123,7 @@ def get_parser():
 
 
 #################################################################################################
-def exe_info(args):
+def system_info():
     for i in range(2, len(sys.argv)):
         file = sys.argv[i]
         try:
@@ -154,6 +151,17 @@ def exe_info(args):
                platform.release(), os.name, platform.machine())
     except:
         pass
+
+    try:
+        from screeninfo import get_monitors
+        for m in get_monitors():
+            pr = '         '
+            if m.is_primary:
+                pr = '(primary)'
+            printc(f"monitor {pr} : {m.name}, resolution=({m.width}, {m.height}), x={m.x}, y={m.y}")
+    except:
+        printc('monitor           : info is unavailable. Try "pip install screeninfo".')
+
     try:
         import k3d
         printc("k3d version       :", k3d.__version__, bold=0, dim=1)
@@ -396,8 +404,12 @@ def exe_eog(args):
                     p.rotate(90)
             elif event.keyPressed=="f":
                     p.flip()
+            elif event.keyPressed=="b":
+                    p.binarize()
             elif event.keyPressed=="i":
                     p.invert()
+            elif event.keyPressed=="I":
+                    plt.colorPicker(event.picked2d, verbose=True)
             elif event.keyPressed=="k":
                     p.enhance()
             elif event.keyPressed=="s":
@@ -418,6 +430,8 @@ def exe_eog(args):
                 printc('  f           to flip image vertically')
                 printc('  t           to rotate image by 90 deg')
                 printc('  i           to invert colors')
+                printc('  I           to pick the color under mouse')
+                printc('  b           to binarize the image')
                 printc('  k           to enhance b&w image')
                 printc('  s           to apply gaussian smoothing')
                 printc('  S           to save image as png')
@@ -455,7 +469,7 @@ def exe_eog(args):
             plt.addHoverLegend(at=i, c='k8', bg='k2', alpha=0.4)
             plt.show(p, axes=0, at=i, mode='image')
         plt.show(interactive=False)
-        plt.resetCamera(xypad=0.05)
+        plt.resetCamera(tight=0.05)
         plt.interactor.Start()
 
     else:
@@ -473,7 +487,7 @@ def exe_eog(args):
         plt.addCallback('key press', vfunc)
         plt.addHoverLegend(c='k8', bg='k2', alpha=0.4)
         plt.show(pic, mode='image',  interactive=False)
-        plt.resetCamera(xypad=0.0)
+        plt.resetCamera(tight=0.0)
         plt.interactor.Start()
 
     plt.close()
@@ -667,13 +681,11 @@ def draw_scene(args):
         if ".npy" in args.files[0] or ".npz" in args.files[0] and nfiles == 1:
 
             objct = io.load(args.files[0], force=args.reload)
-
-            if "Plotter" in str(type(objct)): # loading a full scene
+            if isinstance(objct, Plotter): # loading a full scene
                 objct.show(mode=interactor_mode)
-                return
             else:                             # loading a set of meshes
                 plt.show(objct, mode=interactor_mode)
-                return
+            return
         #########################################################
 
         ds=0
@@ -724,6 +736,10 @@ def draw_scene(args):
                     plt.camera.SetClippingRange(0, ds)
                     plt.show(actor, at=i, interactive=False, zoom=args.zoom, mode=interactor_mode)
                     plt.actors = actors
+                    # if args.no_camera_share: ## BUG
+                        # plt.resetCamera()
+                        # plt.renderers[i].ResetCameraClippingRange()
+                        # print([plt.camera])
                 except AttributeError:
                     # wildcards in quotes make glob return actor as a list :(
                     vedo.logger.error("Please do not use wildcards within single or double quotes")
@@ -748,7 +764,8 @@ def draw_scene(args):
         if plt.axes==4:
             plt.axes=1
 
-        acts = plt.load(args.files, force=args.reload)
+        acts = load(args.files, force=args.reload)
+        plt += acts
         for a in acts:
             if hasattr(a, 'c'): #Picture doesnt have it
                 a.c(args.color)
@@ -940,8 +957,6 @@ def exe_gui(args):
 
         def _run(self):
 
-            tips()
-
             args.files = list(self.filenames)
             if self.colorCB.get() == "by scalar":
                 args.color = None
