@@ -6,7 +6,10 @@ import numpy as np
 import vedo
 import vtk
 
-__doc__ = ("Colors definitions and printing methods." )
+__doc__ = """
+Colors definitions and printing methods. <br>
+.. image:: https://vedo.embl.es/images/basic/colorcubes.png
+"""
 
 __all__ = [
     "printc",
@@ -42,6 +45,118 @@ reset = "\x1b[0m"
 # basic color schemes
 #########################################################
 colors = {
+    # order kind of matters because of pyplot.plot()
+
+    "blue9": "#a8cbfe",      # bootstrap5 colors
+    "blue8": "#81b4fe",
+    "blue7": "#5a9cfe",
+    "blue6": "#3485fd",
+    "blue5": "#0d6efd",
+    "blue4": "#0b5cd5",
+    "blue3": "#094bac",
+    "blue2": "#073984",
+    "blue1": "#05285b",
+
+    "indigo9": "#c8a9fa",
+    "indigo8": "#af83f8",
+    "indigo7": "#975cf6",
+    "indigo6": "#7e36f4",
+    "indigo5": "#6610f2",
+    "indigo4": "#560dcb",
+    "indigo3": "#450ba5",
+    "indigo2": "#35087e",
+    "indigo1": "#250657",
+
+    "purple9": "#cbbbe9",
+    "purple8": "#b49ddf",
+    "purple7": "#9d7ed5",
+    "purple6": "#8660cb",
+    "purple5": "#6f42c1",
+    "purple4": "#5d37a2",
+    "purple3": "#4b2d83",
+    "purple2": "#3a2264",
+    "purple1": "#281845",
+
+    "pink9": "#f0b6d3",
+    "pink8": "#ea95bf",
+    "pink7": "#e374ab",
+    "pink6": "#dd5498",
+    "pink5": "#d63384",
+    "pink4": "#b42b6f",
+    "pink3": "#92235a",
+    "pink2": "#6f1b45",
+    "pink1": "#4d1230",
+
+    "red9": "#f2b6bc",
+    "red8": "#ed969e",
+    "red7": "#e77681",
+    "red6": "#e25563",
+    "red5": "#dc3545",
+    "red4": "#b92d3a",
+    "red3": "#96242f",
+    "red2": "#721c24",
+    "red1": "#4f1319",
+
+    "orange9": "#fed1aa",
+    "orange8": "#febc85",
+    "orange7": "#fea75f",
+    "orange6": "#fd933a",
+    "orange5": "#fd7e14",
+    "orange4": "#d56a11",
+    "orange3": "#ac560e",
+    "orange2": "#84420a",
+    "orange1": "#5b2d07",
+
+    "yellow9": "#ffe9a6",
+    "yellow8": "#ffdf7e",
+    "yellow7": "#ffd556",
+    "yellow6": "#ffcb2f",
+    "yellow5": "#ffc107",
+    "yellow4": "#d6a206",
+    "yellow3": "#ad8305",
+    "yellow2": "#856404",
+    "yellow1": "#5c4503",
+
+    "green9": "#b2dfbc",
+    "green8": "#8fd19e",
+    "green7": "#6dc381",
+    "green6": "#4ab563",
+    "green5": "#28a745",
+    "green4": "#228c3a",
+    "green3": "#1b722f",
+    "green2": "#155724",
+    "green1": "#0e3c19",
+
+    "teal9": "#afecda",
+    "teal8": "#8be3c9",
+    "teal7": "#67dab8",
+    "teal6": "#44d2a8",
+    "teal5": "#20c997",
+    "teal4": "#1ba97f",
+    "teal3": "#168967",
+    "teal2": "#11694f",
+    "teal1": "#0c4836",
+
+    "cyan9": "#abdee5",
+    "cyan8": "#86cfda",
+    "cyan7": "#61c0cf",
+    "cyan6": "#3cb1c3",
+    "cyan5": "#17a2b8",
+    "cyan4": "#13889b",
+    "cyan3": "#106e7d",
+    "cyan2": "#0c5460",
+    "cyan1": "#083a42",
+
+    "gray9": "#f8f9fa",
+    "gray8": "#e9edef",
+    "gray7": "#dee2e6",
+    "gray6": "#ced4da",
+    "gray5": "#adb5bd",
+    "gray4": "#6c757d",
+    "gray3": "#495057",
+    "gray2": "#343a40",
+    "gray1": "#212529",
+
     "aliceblue": "#F0F8FF",      # matplotlib scheme
     "antiquewhite": "#FAEBD7",
     "aqua": "#00FFFF",
@@ -182,140 +297,10 @@ colors = {
     "whitesmoke": "#F5F5F5",
     "yellow": "#ffff36", #"#FFFF00",
     "yellowgreen": "#9ACD32",
-
-    "blue9": "#a8cbfe",      # bootstrap5 colors
-    "blue8": "#81b4fe",
-    "blue7": "#5a9cfe",
-    "blue6": "#3485fd",
-    "blue5": "#0d6efd",
-    "blue4": "#0b5cd5",
-    "blue3": "#094bac",
-    "blue2": "#073984",
-    "blue1": "#05285b",
-
-    "indigo9": "#c8a9fa",
-    "indigo8": "#af83f8",
-    "indigo7": "#975cf6",
-    "indigo6": "#7e36f4",
-    "indigo5": "#6610f2",
-    "indigo4": "#560dcb",
-    "indigo3": "#450ba5",
-    "indigo2": "#35087e",
-    "indigo1": "#250657",
-
-    "purple9": "#cbbbe9",
-    "purple8": "#b49ddf",
-    "purple7": "#9d7ed5",
-    "purple6": "#8660cb",
-    "purple5": "#6f42c1",
-    "purple4": "#5d37a2",
-    "purple3": "#4b2d83",
-    "purple2": "#3a2264",
-    "purple1": "#281845",
-
-    "pink9": "#f0b6d3",
-    "pink8": "#ea95bf",
-    "pink7": "#e374ab",
-    "pink6": "#dd5498",
-    "pink5": "#d63384",
-    "pink4": "#b42b6f",
-    "pink3": "#92235a",
-    "pink2": "#6f1b45",
-    "pink1": "#4d1230",
-
-    "red9": "#f2b6bc",
-    "red8": "#ed969e",
-    "red7": "#e77681",
-    "red6": "#e25563",
-    "red5": "#dc3545",
-    "red4": "#b92d3a",
-    "red3": "#96242f",
-    "red2": "#721c24",
-    "red1": "#4f1319",
-
-    "orange9": "#fed1aa",
-    "orange8": "#febc85",
-    "orange7": "#fea75f",
-    "orange6": "#fd933a",
-    "orange5": "#fd7e14",
-    "orange4": "#d56a11",
-    "orange3": "#ac560e",
-    "orange2": "#84420a",
-    "orange1": "#5b2d07",
-
-    "yellow9": "#ffe9a6",
-    "yellow8": "#ffdf7e",
-    "yellow7": "#ffd556",
-    "yellow6": "#ffcb2f",
-    "yellow5": "#ffc107",
-    "yellow4": "#d6a206",
-    "yellow3": "#ad8305",
-    "yellow2": "#856404",
-    "yellow1": "#5c4503",
-
-    "green9": "#b2dfbc",
-    "green8": "#8fd19e",
-    "green7": "#6dc381",
-    "green6": "#4ab563",
-    "green5": "#28a745",
-    "green4": "#228c3a",
-    "green3": "#1b722f",
-    "green2": "#155724",
-    "green1": "#0e3c19",
-
-    "teal9": "#afecda",
-    "teal8": "#8be3c9",
-    "teal7": "#67dab8",
-    "teal6": "#44d2a8",
-    "teal5": "#20c997",
-    "teal4": "#1ba97f",
-    "teal3": "#168967",
-    "teal2": "#11694f",
-    "teal1": "#0c4836",
-
-    "cyan9": "#abdee5",
-    "cyan8": "#86cfda",
-    "cyan7": "#61c0cf",
-    "cyan6": "#3cb1c3",
-    "cyan5": "#17a2b8",
-    "cyan4": "#13889b",
-    "cyan3": "#106e7d",
-    "cyan2": "#0c5460",
-    "cyan1": "#083a42",
-
-    "gray9": "#f8f9fa",
-    "gray8": "#e9edef",
-    "gray7": "#dee2e6",
-    "gray6": "#ced4da",
-    "gray5": "#adb5bd",
-    "gray4": "#6c757d",
-    "gray3": "#495057",
-    "gray2": "#343a40",
-    "gray1": "#212529",
-
 }
 
 
 color_nicks = {  # color nicknames
-    "a": "aqua",
-    "b": "blue",
-    "c": "cyan",
-    "d": "gold",
-    "f": "fuchsia",
-    "g": "green",
-    "i": "indigo",
-    "k": "black",
-    "m": "magenta",
-    "n": "navy",
-    "l": "lavender",
-    "o": "orange",
-    "p": "purple",
-    "r": "red",
-    "s": "salmon",
-    "t": "tomato",
-    "v": "violet",
-    "y": "yellow",
-    "w": "white",
     "bb": "blackboard",
     "lb": "lightblue",  # light
     "lg": "lightgreen",
@@ -402,6 +387,25 @@ color_nicks = {  # color nicknames
     "k7": "gray7",
     "k8": "gray8",
     "k9": "gray9",
+    "a": "aqua",
+    "b": "blue",
+    "c": "cyan",
+    "d": "gold",
+    "f": "fuchsia",
+    "g": "green",
+    "i": "indigo",
+    "k": "black",
+    "m": "magenta",
+    "n": "navy",
+    "l": "lavender",
+    "o": "orange",
+    "p": "purple",
+    "r": "red",
+    "s": "salmon",
+    "t": "tomato",
+    "v": "violet",
+    "y": "yellow",
+    "w": "white",
 }
 
 
@@ -451,45 +455,93 @@ cmaps_names = (
 )
 
 
-# default sets of colors
-colors1 = [
-    [1.0, 0.832, 0.000],  # gold
-    [0.960, 0.509, 0.188],
-    [0.901, 0.098, 0.194],
-    [0.235, 0.85, 0.294],
-    [0.46, 0.48, 0.000],
-    [0.274, 0.941, 0.941],
-    [0.0, 0.509, 0.784],
-    [0.1, 0.1, 0.900],
-    [0.902, 0.7, 1.000],
-    [0.941, 0.196, 0.901],
-]
-# negative integer color number get this:
-colors2 = [
-    (0.99, 0.83, 0),    # gold
-    (0.59, 0.0, 0.09),  # dark red
-    (0.5, 1.0, 0.0),    # green
-    (0.5, 0.5, 0),      # yellow-green
-    (0.0, 0.66, 0.42),  # green blue
-    (0.0, 0.18, 0.65),  # blue
-    (0.4, 0.0, 0.4),    # plum
-    (0.4, 0.0, 0.6),
-    (0.2, 0.4, 0.6),
-    (0.1, 0.3, 0.2),
-]
+# default color palettes when using an index
+palettes = (
+    (
+        (1.0, 0.832, 0.000),  # gold
+        (0.960, 0.509, 0.188),
+        (0.901, 0.098, 0.194),
+        (0.235, 0.85, 0.294),
+        (0.46, 0.48, 0.000),
+        (0.274, 0.941, 0.941),
+        (0.0, 0.509, 0.784),
+        (0.1, 0.1, 0.900),
+        (0.902, 0.7, 1.000),
+        (0.941, 0.196, 0.901),
+    ),
+    (
+        (1.0, 0.832, 0),    # gold
+        (0.59, 0.0, 0.09),  # dark red
+        (0.5, 0.5, 0),      # yellow-green
+        (0.0, 0.66, 0.42),  # green blue
+        (0.5, 1.0, 0.0),    # green
+        (0.0, 0.18, 0.65),  # blue
+        (0.4, 0.0, 0.4),    # plum
+        (0.4, 0.0, 0.6),
+        (0.2, 0.4, 0.6),
+        (0.1, 0.3, 0.2),
+    ),
+    (
+        (0.010, 0.0706, 0.098),  #  -> black
+        (0.0196, 0.369, 0.447),
+        (0.0745, 0.573, 0.584),
+        (0.584, 0.820, 0.741),
+        (0.914, 0.847, 0.663),
+        (0.929, 0.616, 0.149),
+        (0.788, 0.412, 0.110),
+        (0.729, 0.259, 0.0902),
+        (0.678, 0.153, 0.110),
+        (0.604, 0.153, 0.165),  #  -> red3
+    ),
+    (
+        (0.345, 0.188, 0.071),  #  -> orange1
+        (0.498, 0.314, 0.161),
+        (0.573, 0.404, 0.239),
+        (0.651, 0.545, 0.400),
+        (0.714, 0.678, 0.569),
+        (0.761, 0.773, 0.671),
+        (0.643, 0.675, 0.533),
+        (0.396, 0.427, 0.298),
+        (0.255, 0.282, 0.204),
+        (0.200, 0.239, 0.165),  #  -> blackboard
+    ),
+    (
+        (0.937, 0.969, 0.820),  #  -> beige
+        (0.729, 0.851, 0.714),
+        (0.671, 0.639, 0.396),
+        (0.447, 0.180, 0.180),
+        (0.259, 0.055, 0.082),  #  -> red1
+        (0.937, 0.969, 0.820),  #  -> beige
+        (0.729, 0.851, 0.714),
+        (0.671, 0.639, 0.396),
+        (0.447, 0.180, 0.180),
+        (0.259, 0.055, 0.082),  #  -> red1
+    ),
+    (
+        (0.933, 0.298, 0.443),  #  -> red6
+        (0.996, 0.824, 0.431),
+        (0.082, 0.835, 0.631),
+        (0.094, 0.537, 0.690),
+        (0.035, 0.231, 0.294),  #  -> cyan1
+        (0.933, 0.298, 0.443),  #  -> red6
+        (0.996, 0.824, 0.431),
+        (0.082, 0.835, 0.631),
+        (0.094, 0.537, 0.690),
+        (0.035, 0.231, 0.294),  #  -> cyan1
+    ),
+)
 
 
 emoji = {
-    "\bomb": u"\U0001F4A5",
-    "\sparks": u"\U00002728",
-    "\ethumbup": u"\U0001F44d",
+    "\bomb" : u"\U0001F4A5",
+    "\sparks" : u"\U00002728",
+    "\ethumbup" : u"\U0001F44d",
     "\etarget": u"\U0001F3af",
     "\save": u"\U0001F4be",
     "\noentry": u"\U000026d4",
     "\video": u"\U0001F4fd ",
     "\lightning": u"\U000026a1",
     "\camera": u"\U0001F4f8",
-    "\!?": u"\U00002049",
     "\times": u"\U0000274c",
     "\world": u"\U0001F30d",
     "\erainbow": u"\U0001F308",
@@ -497,7 +549,6 @@ emoji = {
     "\pin": u"\U0001F4CC",
     "\construction": u"\U0001F6A7",
     "\rightarrow": u"\U000027a1",
-    "\minus": u"\U00002796",
     "\erocket": u"\U0001F680",
     "\hourglass": u"\U000023f3",
     "\prohibited": u"\U0001F6ab",
@@ -524,7 +575,7 @@ def _has_colors(stream):
         return curses.tigetnum("colors") > 2
     except:
         return False
-
+#
 _terminal_has_colors = _has_colors(sys.stdout)
 
 
@@ -542,7 +593,7 @@ def getColor(rgb=None, hsv=None):
     """
     Convert a color or list of colors to (r,g,b) format from many different input formats.
 
-    :param bool hsv: if set to `True`, rgb is assumed as (hue, saturation, value).
+    Set ``hsv`` to input as (hue, saturation, value).
 
     Example:
          - RGB    = (255, 255, 255), corresponds to white
@@ -554,7 +605,8 @@ def getColor(rgb=None, hsv=None):
          - int    =  7 picks color nr. 7 in a predefined color list
          - int    = -7 picks color nr. 7 in a different predefined list
 
-    |colorcubes| |colorcubes.py|_
+
+    .. hint:: examples/basic/colorcubes.py
     """
     # recursion, return a list if input is list of colors:
     if _isSequence(rgb) and (len(rgb) > 3 or _isSequence(rgb[0])):
@@ -616,27 +668,14 @@ def getColor(rgb=None, hsv=None):
             namedColors.GetColor(c, rgba)
             return (rgba[0]/255.0, rgba[1]/255.0, rgba[2]/255.0)
 
-    elif isinstance(c, int):  # color number
-        if c >= 0:
-            return colors1[c % 10]
-        else:
-            return colors2[-c % 10]
-
-    elif isinstance(c, float):
-        if c >= 0:
-            return colors1[int(c) % 10]
-        else:
-            return colors2[int(-c) % 10]
+    elif isinstance(c, (int, float)):  # color number
+        return palettes[vedo.settings.palette % len(palettes)][abs(int(c)) % 10]
 
     # print("Unknown color:", c)
     return (0.5, 0.5, 0.5)
 
 def getColorName(c):
-    """
-    Find the name of a color.
-
-    |colorpalette| |colorpalette.py|_
-    """
+    """Find the name of a color."""
     c = np.array(getColor(c))  # reformat to rgb
     mdist = 99.0
     kclosest = ""
@@ -674,34 +713,40 @@ def hex2rgb(hx):
         return (rgb255[0]/255., rgb255[1]/255., rgb255[2]/255.)
 
 def colorMap(value, name="jet", vmin=None, vmax=None):
-    """Map a real value in range [vmin, vmax] to a (r,g,b) color scale.
+    """
+    Map a real value in range [vmin, vmax] to a (r,g,b) color scale.
 
-    :param value: scalar value to transform into a color
-    :type value: float, list
-    :param name: color map name
-    :type name: str, matplotlib.colors.LinearSegmentedColormap
+    Return the (r,g,b) color, or a list of (r,g,b) colors.
 
-    :return: (r,g,b) color, or a list of (r,g,b) colors.
+    Parameters
+    ----------
+    value : float, list
+        scalar value to transform into a color
+
+    name : str, matplotlib.colors.LinearSegmentedColormap
+        color map name
 
     .. note:: Most frequently used color maps:
 
-        |colormaps|
+        .. image:: https://user-images.githubusercontent.com/32848391/50738804-577e1680-11d8-11e9-929e-fca17a8ac6f3.jpg
 
         Color maps list:
 
         .. image:: https://matplotlib.org/1.2.1/_images/show_colormaps.png
 
-    .. tip:: Can also directly use and customize a matplotlib color map:
+    .. note:: Can also directly use and customize a matplotlib color map
 
-        :Example:
+    Example:
+        .. code-block:: python
 
-            .. code-block:: python
+            from vedo import colorMap
+            import matplotlib.cm as cm
+            print( colorMap(0.2, cm.flag, 0, 1) )
 
-                from vedo import colorMap
-                import matplotlib.cm as cm
-                print( colorMap(0.2, cm.flag, 0, 1) )
+            # (1.0, 0.809016994374948, 0.6173258487801733)
 
-                (1.0, 0.809016994374948, 0.6173258487801733)
+    .. hint:: examples/pyplot/plot_bars.py
+        .. image:: https://vedo.embl.es/images/pyplot/plot_bars.png
     """
     cut = _isSequence(value) # to speed up later
 
@@ -761,12 +806,22 @@ def buildPalette(color1, color2, N, hsv=True):
     Generate N colors starting from `color1` to `color2`
     by linear interpolation in HSV or RGB spaces.
 
-    :param int N: number of output colors.
-    :param color1: first rgb color.
-    :param color2: second rgb color.
-    :param bool hsv: if `False`, interpolation is calculated in RGB space.
+    Parameters
+    ----------
+    N : int
+        number of output colors.
 
-    .. hint:: Example: |colorpalette.py|_
+    color1 : color
+        first color.
+
+    color2 : color
+        second color.
+
+    hsv : bool
+        if `False`, interpolation is calculated in RGB space.
+
+    .. hint:: examples/basic/mesh_custom.py
+        .. image:: https://vedo.embl.es/images/basic/mesh_custom.png
     """
     if hsv:
         color1 = rgb2hsv(color1)
@@ -782,38 +837,52 @@ def buildPalette(color1, color2, N, hsv=True):
     return np.array(cols)
 
 
-def buildLUT(colorlist,
-             vmin=None, vmax=None,
-             belowColor=None, aboveColor=None, nanColor=None,
-             belowAlpha=1, aboveAlpha=1, nanAlpha=1,
-             interpolate=False,
+def buildLUT(
+        colorlist,
+        vmin=None, vmax=None,
+        belowColor=None, aboveColor=None, nanColor=None,
+        belowAlpha=1, aboveAlpha=1, nanAlpha=1,
+        interpolate=False,
     ):
     """
     Generate colors in a lookup table (LUT).
 
-    :param list colorlist: a list in the form ``[(scalar1, [r,g,b]), (scalar2, 'blue'), ...]``.
+    Return the ``vtkLookupTable`` object. This can be fed into ``cmap()`` method.
 
-    :param float vmin: specify minimum value of scalar range
+    Parameters
+    ----------
+    colorlist : list
+        a list in the form ``[(scalar1, [r,g,b]), (scalar2, 'blue'), ...]``.
 
-    :param float vmax: specify maximum value of scalar range
+    vmin : float
+        specify minimum value of scalar range
 
-    :param belowColor: color for scalars below the minimum in range
+    vmax : float
+        specify maximum value of scalar range
 
-    :param belowAlpha: alpha for scalars below the minimum in range
+    belowColor : color
+        color for scalars below the minimum in range
 
-    :param aboveColor: color for scalars above the maximum in range
+    belowAlpha : float
+        opacity for scalars below the minimum in range
 
-    :param aboveAlpha: alpha for scalars above the maximum in range
+    aboveColor : color
+        color for scalars above the maximum in range
 
-    :param nanColor: color for invalid (nan) scalars
+    aboveAlpha : float
+        alpha for scalars above the maximum in range
 
-    :param nanAlpha: alpha for invalid (nan) scalars
+    nanColor : color
+        color for invalid (nan) scalars
 
-    :param bool interpolate: interpolate or not intermediate scalars
+    nanAlpha : float
+        alpha for invalid (nan) scalars
 
-    :return: the lookup table object ``vtkLookupTable``. This can be fed into ``cmap``.
+    interpolate : bool
+        interpolate or not intermediate scalars
 
-    .. hint:: Example: |mesh_lut.py|_
+    .. hint:: examples/basic/mesh_lut.py
+        .. image:: https://vedo.embl.es/images/basic/mesh_lut.png
     """
     ctf = vtk.vtkColorTransferFunction()
     ctf.SetColorSpaceToRGB()
@@ -872,37 +941,63 @@ def buildLUT(colorlist,
     return lut
 
 #########################################################################
-def printc(*strings,
-            c = None,
-            bc = None,
-            bold = True,
-            italic = False,
-            blink = False,
-            underline = False,
-            strike = False,
-            dim = False,
-            invert = False,
-            box = "",
-            end = "\n",
-            flush = True,
+def printc(
+        *strings,
+        c = None,
+        bc = None,
+        bold = True,
+        italic = False,
+        blink = False,
+        underline = False,
+        strike = False,
+        dim = False,
+        invert = False,
+        box = "",
+        end = "\n",
+        flush = True,
     ):
     """
     Print to terminal in color (any color!).
 
-    :param c: foreground color name or (r,g,b)
-    :param bc: background color name or (r,g,b)
-    :param bool bold: boldface [True]
-    :param bool italic: italic [False]
-    :param bool blink: blinking text [False]
-    :param bool underline: underline text [False]
-    :param bool strike: strike through text [False]
-    :param bool dim: make text look dimmer [False]
-    :param bool invert: invert background and forward colors [False]
-    :param box: print a box with specified text character ['']
-    :param bool flush: flush buffer after printing [True]
-    :param str end: the end character to be printed [newline]
+    Parameters
+    ----------
+    c : color
+        foreground color name or (r,g,b)
 
-    :Example:
+    bc : color
+        background color name or (r,g,b)
+
+    bold : bool
+        boldface [True]
+
+    italic : bool
+        italic [False]
+
+    blink : bool
+        blinking text [False]
+
+    underline : bool
+        underline text [False]
+
+    strike : bool
+        strike through text [False]
+
+    dim : bool
+        make text look dimmer [False]
+
+    invert : bool
+        invert background and forward colors [False]
+
+    :param box : bool
+        print a box with specified text character ['']
+
+    flush : bool
+        flush buffer after printing [True]
+
+    end : str
+        the end character to be printed [newline]
+
+    Example:
         .. code-block:: python
 
             from vedo.colors import printc
@@ -910,7 +1005,8 @@ def printc(*strings,
             printc('anything', 455.5, c='lightblue')
             printc(299792.48, c=4)
 
-    |colorprint| |colorprint.py|_
+    .. hint:: examples/other/printc.py
+        .. image:: https://user-images.githubusercontent.com/32848391/50739010-2bfc2b80-11da-11e9-94de-011e50a86e61.jpg
     """
     if not vedo.settings.enablePrintColor:
         print(*strings, end=end, flush=flush)
@@ -1027,7 +1123,7 @@ def printd(*strings, q=False):
     Print debug information about the evironment where the printd() is called.
     Local variables are printed out with their current values.
 
-    :param bool q: quit (exit) python session after the printd call.
+    Use ``q`` to quit (exit) python session after the printd call.
     """
     from inspect import currentframe, getframeinfo
     from vedo.utils import isSequence, precision
