@@ -30,6 +30,10 @@ __all__ = [
     "makeBands",
     "spher2cart",
     "cart2spher",
+    "cart2cyl",
+    "cyl2cart",
+    "cyl2spher",
+    "spher2cyl",
     "cart2pol",
     "pol2cart",
     "humansort",
@@ -51,7 +55,7 @@ class ProgressBar:
     """
     Class to print a progress bar with optional text message.
 
-    :Example:
+    Example:
         .. code-block:: python
 
             import time
@@ -60,20 +64,22 @@ class ProgressBar:
                 time.sleep(.1)
                 pb.print('some message')
 
-        |progbar|
+       .. image:: https://user-images.githubusercontent.com/32848391/51858823-ed1f4880-2335-11e9-8788-2d102ace2578.png
     """
-
-    def __init__(self,
-                 start, stop, step=1,
-                 c=None,
-                 bold=True,
-                 italic=False,
-                 title='',
-                 ETA=True,
-                 width=25,
-                 char=u"\U00002501",
-                 char_back=u"\U00002500",
-                 ):
+    def __init__(
+            self,
+            start,
+            stop,
+            step=1,
+            c=None,
+            bold=True,
+            italic=False,
+            title='',
+            ETA=True,
+            width=25,
+            char=u"\U00002501",
+            char_back=u"\U00002500",
+        ):
 
         char_arrow = ""
         if sys.version_info[0]<3:
@@ -100,7 +106,8 @@ class ProgressBar:
         self.width = width
         self.char = char
         self.bar = ""
-        self.percent = 0
+        self.percent = 0.
+        self.percent_int = 0
         self.ETA = ETA
         self.clock0 = time.time()
         self._remt = 1e10
@@ -160,7 +167,7 @@ class ProgressBar:
             vedo.printc(s, c=c, bold=self.bold, italic=self.italic, end="")
             sys.stdout.flush()
 
-            if self.percent == 100:
+            if self.percent == 100.:
                 print("")
             self._lentxt = len(txt)
 
@@ -178,31 +185,31 @@ class ProgressBar:
         elif counts > self.stop:
             counts = self.stop
         self._counts = counts
-        self.percent = (self._counts - self.start) * 100
+        self.percent = (self._counts - self.start) * 100.
         dd = self.stop - self.start
         if dd:
             self.percent /= self.stop - self.start
         else:
-            self.percent = 0
-        self.percent = int(round(self.percent))
+            self.percent = 0.
+        self.percent_int = int(round(self.percent))
         af = self.width - 2
-        nh = int(round(self.percent / 100 * af))
+        nh = int(round(self.percent_int / 100 * af))
         br_bk = "\x1b[2m"+self.char_back*(af-nh)
         br = "%s%s%s" % (self.char*(nh-1), self.char_arrow, br_bk)
         self.bar = self.title + self.char0 + br + self.char1
-        if self.percent < 100:
-            ps = " " + str(self.percent) + "%"
+        if self.percent < 100.:
+            ps = " " + str(self.percent_int) + "%"
         else:
             ps = ""
         self.bar += ps
 
 
+###########################################################
 class dotdict(dict):
     """
     A dictionary supporting dot notation.
 
     Example:
-
         .. code-block:: python
 
             dd = dotdict({"a": 1,
@@ -235,18 +242,20 @@ class dotdict(dict):
                 self[k] = dotdict(v)
 
     def __getattr__(self, k):
+        if '__getstate__' in k: # a trick to make spyder happy when inspecting dotdict
+            def _dummy():
+                pass
+            return _dummy
         return self[k]
 
     def __setattr__(self, k, v):
         if self.warn_on_setting:
-            if k not in self:
-                vedo.logger.warning(f'you are setting non-existing {k} to {v}')
+            if k not in self and not k.startswith('__'):
+                vedo.logger.warning(f'you are setting non-existing key {k} to {v}')
         self[k] = v
 
     def lookup(self, dotkey):
-        """
-        Lookup value in a nested structure with a single key, e.g. "a.b.c".
-        """
+        """Lookup value in a nested structure with a single key, e.g. "a.b.c"."""
         path = list(reversed(dotkey.split(".")))
         v = self
         while path:
@@ -262,8 +271,7 @@ class dotdict(dict):
 
 ###########################################################
 def numpy2vtk(arr, dtype=None, deep=True, name=""):
-    """Convert a numpy array into a vtkDataArray.
-    Use dtype='id' for vtkIdTypeArray objects."""
+    """Convert a numpy array into a `vtkDataArray`. Use dtype='id' for vtkIdTypeArray objects."""
     # https://github.com/Kitware/VTK/blob/master/Wrapping/Python/vtkmodules/util/numpy_support.py
     if arr is None:
         return None
@@ -283,7 +291,7 @@ def numpy2vtk(arr, dtype=None, deep=True, name=""):
     return varr
 
 def vtk2numpy(varr):
-    """Convert a vtkDataArray or vtkIdList into a numpy array"""
+    """Convert a `vtkDataArray` or `vtkIdList` into a numpy array"""
     if isinstance(varr, vtk.vtkIdList):
         return np.array([varr.GetId(i) for i in range(varr.GetNumberOfIds())])
     elif isinstance(varr, vtk.vtkBitArray):
@@ -305,7 +313,7 @@ def geometry(obj, extent=None):
 
     Returns a ``Mesh`` object.
 
-    :param list extent: set a `[xmin,xmax, ymin,ymax, zmin,zmax]` bounding box to clip data.
+    Set `extent` as the `[xmin,xmax, ymin,ymax, zmin,zmax]` bounding box to clip data.
     """
     gf = vtk.vtkGeometryFilter()
     gf.SetInputData(obj)
@@ -317,7 +325,7 @@ def geometry(obj, extent=None):
 
 def buildPolyData(vertices, faces=None, lines=None, indexOffset=0, fast=True, tetras=False):
     """
-    Build a ``vtkPolyData`` object from a list of vertices
+    Build a `vtkPolyData` object from a list of vertices
     where faces represents the connectivity of the polygonal mesh.
 
     E.g. :
@@ -325,13 +333,13 @@ def buildPolyData(vertices, faces=None, lines=None, indexOffset=0, fast=True, te
         - ``faces=[[0,1,2], [1,2,3], ...]``
         - ``lines=[[0,1], [1,2,3,4], ...]``
 
-    Use ``indexOffset=1`` if face numbering starts from 1 instead of 0.
+    Use `indexOffset=1` if face numbering starts from 1 instead of 0.
 
-    If fast=False the mesh is built "manually" by setting polygons and triangles
+    If `fast=False` the mesh is built "manually" by setting polygons and triangles
     one by one. This is the fallback case when a mesh contains faces of
     different number of vertices.
 
-    If tetras=True, interpret 4-point faces as tetrahedrons instead of surface quads.
+    If `tetras=True`, interpret 4-point faces as tetrahedrons instead of surface quads.
     """
     poly = vtk.vtkPolyData()
 
@@ -467,11 +475,16 @@ def buildPolyData(vertices, faces=None, lines=None, indexOffset=0, fast=True, te
 
 ##############################################################################
 def getFontPath(font):
+    """Internal use."""
     if font in vedo.settings.font_parameters.keys():
         if vedo.settings.font_parameters[font]["islocal"]:
             fl = os.path.join(vedo.fonts_path, f'{font}.ttf')
         else:
-            fl = vedo.io.download(f"https://vedo.embl.es/fonts/{font}.ttf", verbose=False)
+            try:
+                fl = vedo.io.download(f"https://vedo.embl.es/fonts/{font}.ttf", verbose=False)
+            except:
+                vedo.logger.warning(f"Could not download https://vedo.embl.es/fonts/{font}.ttf")
+                fl = os.path.join(vedo.fonts_path, 'Normografo.ttf')
     else:
         if font.startswith("https://"):
             fl = vedo.io.download(font, verbose=False)
@@ -482,8 +495,9 @@ def getFontPath(font):
                 vedo.printc("Could not set font file", font,
                        "-> Using default:", vedo.settings.defaultFont, c='r')
             else:
+                vedo.settings.defaultFont = 'Normografo'
                 vedo.printc("Could set font name", font,
-                       "-> Using default:", vedo.settings.defaultFont, c='r')
+                       "-> Using default: Normografo", c='r')
                 vedo.printc("Check https://vedo.embl.es/fonts for additional fonts", c='r')
                 vedo.printc("Type 'vedo -r fonts' to see available fonts", c='g')
             fl = getFontPath(vedo.settings.defaultFont)
@@ -515,11 +529,12 @@ def flatten(list_to_flatten):
 
 
 def humansort(l):
-    """Sort in place a given list the way humans expect.
+    """
+    Sort in place a given list the way humans expect.
 
     NB: input list is modified
 
-    E.g. ['file11', 'file1'] -> ['file1', 'file11']
+    E.g. `['file11', 'file1'] -> ['file1', 'file11']`
     """
     import re
 
@@ -635,7 +650,8 @@ def linInterpolate(x, rangeX, rangeY):
     E.g. if x runs in rangeX=[x0,x1] and I want it to run in rangeY=[y0,y1] then
     y = linInterpolate(x, rangeX, rangeY) will interpolate x onto rangeY.
 
-    |linInterpolate| |linInterpolate.py|_
+    .. hint:: examples/basic/linInterpolate.py
+        .. image:: https://vedo.embl.es/images/basic/linInterpolate.png
     """
     if isSequence(x):
         x = np.asarray(x)
@@ -669,7 +685,8 @@ def linInterpolate(x, rangeX, rangeY):
 
 
 def vector(x, y=None, z=0.0, dtype=np.float64):
-    """Return a 3D numpy array representing a vector.
+    """
+    Return a 3D numpy array representing a vector.
 
     If `y` is ``None``, assume input is already in the form `[x,y,z]`.
     """
@@ -730,11 +747,49 @@ def roundToDigit(x, p):
     else:
         return r
 
+def packSpheres(bounds, radius):
+    """
+    Packing spheres into a bounding box.
+    Returns a numpy array of sphere centers.
+    """
+    h = 0.8164965/2
+    d = 0.8660254
+    a = 0.288675135
+
+    if isSequence(bounds):
+        x0, x1, y0, y1, z0, z1 = bounds
+    else:
+        x0, x1, y0, y1, z0, z1 = bounds.GetBounds()
+
+    x = np.arange(x0, x1, radius)
+    nul = np.zeros_like(x)
+    nz = int((z1-z0)/radius/h/2 +1.5)
+    ny = int((y1-y0)/radius/d +1.5)
+
+    pts = []
+    for iz in range(nz):
+        z = z0 + nul + iz*h*radius
+        dx, dy, dz = [radius*0.5, radius*a, iz*h*radius]
+        for iy in range(ny):
+            y = y0 + nul + iy*d*radius
+            if iy % 2:
+                xs = x
+            else:
+                xs = x + radius*0.5
+            if iz % 2:
+                p = np.c_[xs, y, z] + [dx,dy,dz]
+            else:
+                p = np.c_[xs, y, z] + [ 0, 0,dz]
+            pts += p.tolist()
+    return np.array(pts)
+
+
+
 def precision(x, p, vrange=None, delimiter='e'):
     """
     Returns a string representation of `x` formatted with precision `p`.
 
-    :param float vrange: range in which x exists (to snap x to '0' if below precision).
+    Set `vrange` to the range in which x exists (to snap x to '0' if below precision).
     """
     # Based on the webkit javascript implementation
     # `from here <https://code.google.com/p/webkit-mirror/source/browse/JavaScriptCore/kjs/number_object.cpp>`_,
@@ -811,30 +866,28 @@ def precision(x, p, vrange=None, delimiter='e'):
         out.append(m)
     return "".join(out)
 
-
-# 2d
+##################################################################################
+# 2d ######
 def cart2pol(x, y):
     """2D Cartesian to Polar coordinates conversion."""
     theta = np.arctan2(y, x)
     rho = np.hypot(x, y)
-    return rho, theta
+    return np.array([rho, theta])
 
 def pol2cart(rho, theta):
     """2D Polar to Cartesian coordinates conversion."""
     x = rho * np.cos(theta)
     y = rho * np.sin(theta)
-    return x, y
+    return np.array([x, y])
 
-# 3d
+# 3d ######
 def cart2spher(x, y, z):
     """3D Cartesian to Spherical coordinate conversion."""
     hxy = np.hypot(x, y)
     rho = np.hypot(hxy, z)
-    #if not rho:
-    #    return np.array([0,0,0])
     theta = np.arctan2(hxy, z)
     phi = np.arctan2(y, x)
-    return rho, theta, phi
+    return np.array([rho, theta, phi])
 
 def spher2cart(rho, theta, phi):
     """3D Spherical to Cartesian coordinate conversion."""
@@ -850,9 +903,9 @@ def spher2cart(rho, theta, phi):
 
 def cart2cyl(x,y,z):
     """3D Cartesian to Cylindrical coordinate conversion."""
-    rho = np.sqrt(x*x+y*y+z*z)
+    rho = np.sqrt(x*x + y*y)
     theta = np.arctan2(y, x)
-    return rho, theta, z
+    return np.array([rho, theta, z])
 
 def cyl2cart(rho, theta, z):
     """3D Cylindrical to Cartesian coordinate conversion."""
@@ -862,17 +915,17 @@ def cyl2cart(rho, theta, z):
 
 def cyl2spher(rho,theta,z):
     """3D Cylindrical to Spherical coordinate conversion."""
-    rhos = np.sqrt(rho*rho+z*z)
+    rhos = np.sqrt(rho*rho + z*z)
     phi = np.arctan2(rho, z)
-    return rhos, theta, phi
+    return np.array([rhos, phi, theta])
 
 def spher2cyl(rho, theta, phi):
     """3D Spherical to Cylindrical coordinate conversion."""
-    rhoc = rho * np.sin(phi)
-    z = rho * np.cos(phi)
-    return rhoc, theta, z
-
+    rhoc = rho * np.sin(theta)
+    z = rho * np.cos(theta)
+    return np.array([rhoc, phi, z])
 
+##################################################################################
 def grep(filename, tag, firstOccurrence=False):
     """Greps the line that starts with a specific `tag` string inside the file."""
     import re
@@ -1000,8 +1053,11 @@ def printInfo(obj):
         vedo.printc(" z=(" + bz1 + ", " + bz2 + ")", c="g", bold=0)
 
         if hasattr(actor, "picked3d") and actor.picked3d is not None:
+            idpt   = actor.closestPoint(actor.picked3d, returnPointId=True)
+            idcell = actor.closestPoint(actor.picked3d, returnCellId=True)
             vedo.printc(tab + "  clicked point: ", c="g", bold=1, end="")
-            vedo.printc(vector(actor.picked3d), c="g", bold=0)
+            vedo.printc(precision(actor.picked3d, 6),
+                        f'pointID = {idpt}, cellID = {idcell}', c="g", bold=0)
 
         ptdata = poly.GetPointData()
         cldata = poly.GetCellData()
@@ -1283,6 +1339,21 @@ def printInfo(obj):
         vedo.printc("   level / window: ", c="y", bold=1, end="")
         vedo.printc(obj.level(), '/', obj.window(), c="y", bold=0)
 
+        try:
+            width, height = obj.dimensions()
+            w = 65
+            h = int(height/width * (w-1) * 0.5 + 0.5)
+            img_arr = obj.clone().resize([w,h]).tonumpy()
+            h, w = img_arr.shape[:2]
+            for x in range(h):
+                for y in range(w):
+                    pix = img_arr[x][y]
+                    r, g, b = pix[:3]
+                    print(f"\x1b[48;2;{r};{g};{b}m", end=' ')
+                print("\x1b[0m")
+        except:
+            pass
+
     else:
         vedo.printc(type(obj), invert=1)
         vedo.printc(obj)
@@ -1290,34 +1361,48 @@ def printInfo(obj):
 
 
 def printHistogram(data, bins=10, height=10, logscale=False, minbin=0,
-                   horizontal=False, char=u"\U00002589",
+                   horizontal=False, char=u"\u2588",
                    c=None, bold=True, title='Histogram'):
     """
     Ascii histogram printing.
     Input can also be ``Volume`` or ``Mesh``.
     Returns the raw data before binning (useful when passing vtk objects).
 
-    :param int bins: number of histogram bins
-    :param int height: height of the histogram in character units
-    :param bool logscale: use logscale for frequencies
-    :param int minbin: ignore bins before minbin
-    :param bool horizontal: show histogram horizontally
-    :param str char: character to be used
-    :param str,int c: ascii color
-    :param bool char: use boldface
-    :param str title: histogram title
+    Parameters
+    ----------
+    bins : int
+        number of histogram bins
 
-    :Example:
+    height : int
+        height of the histogram in character units
+
+    logscale : bool
+        use logscale for frequencies
+
+    minbin : int
+        ignore bins before minbin
+
+    horizontal : bool
+        show histogram horizontally
+
+    char : str
+        character to be used
+
+    bold : boold
+        use boldface
+
+    title : str
+        histogram title
+
+    Example:
         .. code-block:: python
 
             from vedo import printHistogram
-            import np as np
+            import numpy as np
             d = np.random.normal(size=1000)
             data = printHistogram(d, c='blue', logscale=True, title='my scalars')
             data = printHistogram(d, c=1, horizontal=1)
             print(np.mean(data)) # data here is same as d
-
-        |printhisto|
     """
     # credits: http://pyinsci.blogspot.com/2009/10/ascii-histograms.html
     # adapted for vedo by M.Musy, 2019
@@ -1416,8 +1501,9 @@ def makeBands(inputlist, numberOfBands):
     """
     Group values of a list into bands of equal value.
 
-    :param int numberOfBands: number of bands, a positive integer > 2.
-    :return: a binned list of the same length as the input.
+    Return a binned list of the same length as the input.
+
+    `numberOfBands` is the number of bands, a positive integer > 2.
     """
     if numberOfBands < 2:
         return inputlist
@@ -1441,22 +1527,25 @@ def makeBands(inputlist, numberOfBands):
 # Functions adapted from:
 # https://github.com/sdorkenw/MeshParty/blob/master/meshparty/trimesh_vtk.py
 def cameraFromQuaternion(pos, quaternion, distance=10000, ngl_correct=True):
-    """Define a ``vtkCamera`` with a particular orientation.
+    """
+    Define a `vtkCamera` with a particular orientation.
 
-        Parameters
-        ----------
-        pos: np.array, list, tuple
-            an iterator of length 3 containing the focus point of the camera
-        quaternion: np.array, list, tuple
-            a len(4) quaternion (x,y,z,w) describing the rotation of the camera
-            such as returned by neuroglancer x,y,z,w all in [0,1] range
-        distance: float
-            the desired distance from pos to the camera (default = 10000 nm)
+    Parameters
+    ----------
+    pos: np.array, list, tuple
+        an iterator of length 3 containing the focus point of the camera
 
-        Returns
-        -------
-        vtk.vtkCamera
-            a vtk camera setup according to these rules.
+    quaternion: np.array, list, tuple
+        a len(4) quaternion (x,y,z,w) describing the rotation of the camera
+        such as returned by neuroglancer x,y,z,w all in [0,1] range
+
+    distance: float
+        the desired distance from pos to the camera (default = 10000 nm)
+
+    Returns
+    -------
+    vtk.vtkCamera
+        a vtk camera setup according to these rules.
     """
     camera = vtk.vtkCamera()
     # define the quaternion in vtk, note the swapped order
@@ -1494,20 +1583,22 @@ def cameraFromQuaternion(pos, quaternion, distance=10000, ngl_correct=True):
 
 
 def cameraFromNeuroglancer(state, zoom=300):
-    """Define a ``vtkCamera`` from a neuroglancer state dictionary.
+    """
+    Define a `vtkCamera` from a neuroglancer state dictionary.
 
-        Parameters
-        ----------
-        state: dict
-            an neuroglancer state dictionary.
-        zoom: float
-            how much to multiply zoom by to get camera backoff distance
-            default = 300 > ngl_zoom = 1 > 300 nm backoff distance.
+    Parameters
+    ----------
+    state: dict
+        an neuroglancer state dictionary.
 
-        Returns
-        -------
-        vtk.vtkCamera
-            a vtk camera setup that matches this state.
+    zoom: float
+        how much to multiply zoom by to get camera backoff distance
+        default = 300 > ngl_zoom = 1 > 300 nm backoff distance.
+
+    Returns
+    -------
+    vtk.vtkCamera
+        a vtk camera setup that matches this state.
     """
     orient = state.get("perspectiveOrientation", [0.0, 0.0, 0.0, 1.0])
     pzoom = state.get("perspectiveZoom", 10.0)
@@ -1518,7 +1609,7 @@ def cameraFromNeuroglancer(state, zoom=300):
 
 def orientedCamera(center=(0,0,0), upVector=(0,1,0), backoffVector=(0,0,1), backoff=1):
     """
-    Generate a ``vtkCamera`` pointed at a specific location,
+    Generate a `vtkCamera` pointed at a specific location,
     oriented with a given up direction, set to a backoff.
     """
     vup = np.array(upVector)
@@ -1533,9 +1624,9 @@ def orientedCamera(center=(0,0,0), upVector=(0,1,0), backoffVector=(0,0,1), back
 
 def vtkCameraToK3D(vtkcam):
     """
-    Convert a ``vtkCamera`` object into a 9-element list to be used by K3D backend.
+    Convert a `vtkCamera` object into a 9-element list to be used by K3D backend.
 
-    Output format is: [posx,posy,posz, targetx,targety,targetz, upx,upy,upz]
+    Output format is: `[posx,posy,posz, targetx,targety,targetz, upx,upy,upz]`.
     """
     cpos = np.array(vtkcam.GetPosition())
     kam = [cpos.tolist()]
@@ -1545,6 +1636,7 @@ def vtkCameraToK3D(vtkcam):
 
 
 def makeTicks(x0, x1, N, labels=None, digits=None):
+    """Internal use."""
     # Copyright M. Musy, 2021, license: MIT.
     ticks_str, ticks_float = [], []
 
@@ -1643,12 +1735,16 @@ def gridcorners(i, nm, size, margin=0, flipy=True):
     ----------
     i : int
         input index of the desired grid square (to be used in ``show(..., at=...)``).
+
     nm : list
         grid shape as (n,m).
+
     size : list
         total size of the grid along x and y.
+
     margin : float, optional
-        keep a small margin between boxes. The default is 0.
+        keep a small margin between boxes.
+
     flipy : bool, optional
         y-coordinate points downwards
 
@@ -1657,7 +1753,7 @@ def gridcorners(i, nm, size, margin=0, flipy=True):
     Two 2D points representing the bottom-left corner and the top-right corner
     of the ``i``-nth box in the grid.
 
-    :Example:
+    Example:
         .. code-block:: python
 
             from vedo import *
@@ -1694,10 +1790,9 @@ def gridcorners(i, nm, size, margin=0, flipy=True):
 #
 #Check the example gallery in: examples/other/trimesh>
 ###########################################################################
-
 def vedo2trimesh(mesh):
     """
-    Convert ``vedo.Mesh`` to ``Trimesh.Mesh`` object.
+    Convert `vedo.mesh.Mesh` to `Trimesh.Mesh` object.
     """
     if isSequence(mesh):
         tms = []
@@ -1723,7 +1818,7 @@ def vedo2trimesh(mesh):
 
 def trimesh2vedo(inputobj):
     """
-    Convert ``Trimesh`` object to ``Mesh(vtkActor)`` or ``Assembly`` object.
+    Convert `Trimesh` object to `Mesh(vtkActor)` or `Assembly` object.
     """
     if isSequence(inputobj):
         vms = []
@@ -1779,6 +1874,7 @@ def trimesh2vedo(inputobj):
 
 
 def vedo2meshlab(vmesh):
+    """Convert a vedo mesh to a meshlab object."""
     try:
         import pymeshlab as mlab
     except RuntimeError:
@@ -1843,6 +1939,7 @@ def vedo2meshlab(vmesh):
 
 
 def meshlab2vedo(mmesh):
+    """Convert a meshlab object to vedo mesh."""
     inputtype = str(type(mmesh))
 
     if "MeshSet" in inputtype:
@@ -1892,12 +1989,18 @@ def meshlab2vedo(mmesh):
 def vtkVersionIsAtLeast(major, minor=0, build=0):
     """
     Check the VTK version.
-    Return ``True`` if the requested VTK version is greater or equal
-    to the actual VTK version.
+    Return ``True`` if the requested VTK version is greater or equal to the actual VTK version.
 
-    :param major: Major version.
-    :param minor: Minor version.
-    :param build: Build version.
+    Parameters
+    ----------
+    major : int
+        Major version.
+
+    minor : int
+        Minor version.
+
+    build : int
+        Build version.
     """
     needed_version = 10000000000*int(major) +100000000*int(minor) +int(build)
     try:
@@ -1914,6 +2017,7 @@ def vtkVersionIsAtLeast(major, minor=0, build=0):
 
 
 def ctf2lut(tvobj):
+    """Internal use."""
     # build LUT from a color transfer function for tmesh or volume
     pr = tvobj.GetProperty()
     if not isinstance(pr, vtk.vtkVolumeProperty):
@@ -1936,15 +2040,16 @@ def ctf2lut(tvobj):
 
 
 def resampleArrays(source, target, tol=None):
-    """Resample point and cell data of a dataset on points from another dataset.
+    """
+    Resample point and cell data of a dataset on points from another dataset.
     It takes two inputs - source and target, and samples the point and cell values
     of target onto the point locations of source.
     The output has the same structure as the source but its point data have
     the resampled values from target.
 
-    :param float tol: set the tolerance used to compute whether
-        a point in the target is in a cell of the source.
-        Points without resampled values, and their cells, are be marked as blank.
+    `tol` sets the tolerance used to compute whether
+    a point in the target is in a cell of the source.
+    Points without resampled values, and their cells, are be marked as blank.
     """
     rs = vtk.vtkResampleWithDataSet()
     rs.SetInputData(source.polydata())
